referrerpolicy=no-referrer-when-downgrade

Config

Trait Config 

pub trait Config: Config {
    // Required method
    fn generate_session_keys_and_proof(
        owner: Self::AccountId,
    ) -> (Self::Keys, Vec<u8>);
}

Required Methods

fn generate_session_keys_and_proof( owner: Self::AccountId, ) -> (Self::Keys, Vec<u8>)

Generate a session key and a proof of ownership.

The given owner is the account that will call set_keys using the returned session keys and proof. This means that the proof should prove the ownership of owner over the private keys associated to the session keys.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors